package com.ruoyi.ss.device.service;

import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.ss.device.domain.SmDevice;
import com.ruoyi.ss.device.domain.SmDeviceVo;
import com.ruoyi.ss.store.domain.StoreVo;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.ss.deviceTenant.domain.SmDeviceTenant;
import com.ruoyi.ss.deviceTenant.service.ISmDeviceTenantService;
import com.ruoyi.ss.user.service.ISmUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/4/13
 */
@Service
public class DeviceAssemblerImpl implements DeviceAssembler {

    @Autowired
    private ISmUserService userService;

    @Autowired
    private ISmDeviceTenantService deviceTenantService;

    @Autowired
    private IStoreService smDeviceGroupService;

    @Override
    public void assembleTenant(List<SmDeviceVo> list) {
        if (CollectionUtils.isEmpty(list)) {
            return;
        }
        Map<Long, List<SmDeviceTenant>> tenantGroup = deviceTenantService.selectGroupByDeviceIds(list.stream().map(SmDeviceVo::getDeviceId).collect(Collectors.toList()));

        for (SmDeviceVo device : list) {
            List<SmDeviceTenant> tenants = tenantGroup.get(device.getDeviceId());
            if (CollectionUtils.isEmpty(tenants)) {
                continue;
            }
            device.setTenantIds(tenants.stream().map(SmDeviceTenant::getTenantId).collect(Collectors.toList()));
        }

    }

    @Override
    public void setGroup(SmDevice device) {
        // 房东的默认店铺
        if (device.getUserId() != null && device.getStoreId() == null) {
            StoreVo defaultStore = smDeviceGroupService.selectDefaultStore(device.getUserId());
            if (defaultStore == null) {
                defaultStore = smDeviceGroupService.insertDefaultStore(device.getUserId());
                ServiceUtil.assertion(defaultStore == null, "该用户没有默认店铺");
            }
            device.setStoreId(defaultStore.getStoreId());
        }
    }
}
