package com.ruoyi.ss.store.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonView;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.domain.JsonViewProfile;
import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.valid.EnumValid;
import com.ruoyi.ss.store.domain.enums.StoreType;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.time.LocalTime;

/**
 * 商户对象 sm_device_group
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
@Data
public class Store extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** id */
    @ApiModelProperty("商户id")
    @NotNull(message = "商户id不能为空", groups = {ValidGroup.Update.class})
    private Long storeId;

    /** 商户名称 */
    @Excel(name = "商户名称")
    @ApiModelProperty("商户名称")
    @NotNull(message = "商户名称不能为空", groups = {ValidGroup.Create.class})
    private String name;

    /** 用户 */
    @Excel(name = "用户")
    @ApiModelProperty("用户id")
    @NotNull(message = "用户id不能为空", groups = {ValidGroup.Create.class})
    private Long userId;

    /** 商户图片 */
    @Excel(name = "商户图片")
    private String picture;

    /** 门店地址 */
    @Excel(name = "门店地址")
    @NotNull(message = "门店地址不能为空", groups = {ValidGroup.Create.class})
    private String address;

    /** 定位经度 */
    @Excel(name = "定位经度")
    @NotNull(message = "定位经度不能为空", groups = {ValidGroup.Create.class})
    private BigDecimal lng;

    /** 定位纬度 */
    @Excel(name = "定位纬度")
    @NotNull(message = "定位纬度不能为空", groups = {ValidGroup.Create.class})
    private BigDecimal lat;

    /** 设备排序 */
    @ApiModelProperty("设备排序，越小越靠前")
    private Integer groupSort;

    @ApiModelProperty("是否默认")
    private Boolean isDefault;

    /** 营业时间起始 */
    @Excel(name = "营业时间起始", width = 30, dateFormat = "HH:mm")
    @DateTimeFormat(pattern = "HH:mm")
    @JsonFormat(pattern = "HH:mm", timezone = "GMT+8")
    @NotNull(message = "营业时间起始不能为空", groups = {ValidGroup.Create.class})
    private LocalTime businessTimeStart;

    /** 营业时间结束 */
    @Excel(name = "营业时间结束", width = 30, dateFormat = "HH:mm")
    @DateTimeFormat(pattern = "HH:mm")
    @JsonFormat(pattern = "HH:mm", timezone = "GMT+8")
    @NotNull(message = "营业时间结束不能为空", groups = {ValidGroup.Create.class})
    private LocalTime businessTimeEnd;

    /** 省 */
    @Excel(name = "省")
    @NotNull(message = "省不能为空", groups = {ValidGroup.Create.class})
    private String province;

    /** 市 */
    @Excel(name = "市")
    @NotNull(message = "市不能为空", groups = {ValidGroup.Create.class})
    private String city;

    /** 区县 */
    @Excel(name = "区县")
    @NotNull(message = "区县不能为空", groups = {ValidGroup.Create.class})
    private String county;

    /** 详细地址 */
    @Excel(name = "详细地址")
    @Size(max = 200, message = "详细地址长度不能超过200个字符")
    private String specificAddress;

    @Excel(name = "店铺类型")
    @ApiModelProperty("店铺类型（1：商场，2：学校，3：娱乐场所，4：出租房，5：其它）")
    @NotNull(message = "店铺类型不允许为空", groups = {ValidGroup.Create.class})
    @EnumValid(
            clazz = StoreType.class,
            message = "非法的店铺类型"
    )
    private String type;

}
