package com.ruoyi.ss.store.mapper;

import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.domain.StoreVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 商户Mapper接口
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
public interface StoreMapper
{
    /**
     * 查询商户
     *
     * @param groupId 商户主键
     * @return 商户
     */
    public StoreVo selectSmStoreById(Long groupId);

    /**
     * 查询商户列表
     *
     * @param store 商户
     * @return 商户集合
     */
    public List<StoreVo> selectSmStoreList(Store store);

    /**
     * 新增商户
     *
     * @param store 商户
     * @return 结果
     */
    public int insertSmStore(Store store);

    /**
     * 修改商户
     *
     * @param store 商户
     * @return 结果
     */
    public int updateSmStore(Store store);

    /**
     * 删除商户
     *
     * @param groupId 商户主键
     * @return 结果
     */
    public int deleteSmStoreById(Long groupId);

    /**
     * 批量删除商户
     *
     * @param groupIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSmStoreByIds(Long[] groupIds);

    /**
     * 修改数据的排序
     * @param start 排序范围起始
     * @param end 排序范围结束
     * @param offset 偏移量
     */
    int updateSort(@Param("start") Integer start, @Param("end") Integer end, @Param("offset") Integer offset);

    /**
     * 根据id列表查询数据
     * @param groupIds
     * @return
     */
    List<StoreVo> selectSmStoreByIds(@Param("groupIds") List<Long> groupIds);

    /**
     * 批量更新
     * @param list
     * @return
     */
    int batchUpdate(@Param("list")List<Store> list);

    /**
     * 逻辑删除
     * @param ids
     * @return
     */
    int logicDel(@Param("ids") List<Long> ids);
}
