package com.ruoyi.ss.store.service;

import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVo;

import java.util.List;

/**
 * 商户Service接口
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
public interface IStoreService
{
    /**
     * 查询商户
     *
     * @param groupId 商户主键
     * @return 商户
     */
    public StoreVo selectSmStoreById(Long groupId);

    /**
     * 查询商户列表
     *
     * @param store 商户
     * @return 商户集合
     */
    public List<StoreVo> selectSmStore(StoreQuery store);

    /**
     * 新增商户
     *
     * @param store 商户
     * @return 结果
     */
    public int insertSmStore(Store store);

    /**
     * 修改商户
     *
     * @param store 商户
     * @return 结果
     */
    public int updateSmStore(Store store);

    /**
     * 批量删除商户
     *
     * @param groupIds 需要删除的商户主键集合
     * @return 结果
     */
    public int deleteSmStoreByIds(Long[] groupIds);

    /**
     * 删除商户信息
     *
     * @param groupId 商户主键
     * @return 结果
     */
    public int deleteSmStoreById(Long groupId);

    /**
     * 调整商户位置
     * @param list 调整后的商户列表
     */
    boolean changeSort(List<Store> list);

    /**
     * 查询商户下的设备及其设备数量
     * @param store 查询条件
     * @return 设备列表
     */
    List<StoreVo> listCount(Store store);

    /**
     * 查询用户的默认商户
     * @param userId
     */
    StoreVo selectDefaultStore(Long userId);

    /**
     * 为用户创建一个默认的商户
     * @param userId
     * @return
     */
    StoreVo insertDefaultStore(Long userId);

    /**
     * ids逻辑删除
     * @param ids id列表
     */
    int logicDel(List<Long> ids);
}
