package com.ruoyi.ss.store.service.impl;

import com.ruoyi.common.core.domain.BaseValidator;
import com.ruoyi.common.core.domain.ValidateResult;
import com.ruoyi.ss.device.domain.SmDeviceQuery;
import com.ruoyi.ss.device.service.ISmDeviceService;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.ss.store.service.StoreValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 2024/4/27
 *
 * @author wjh
 */
@Service
public class StoreValidatorImpl extends BaseValidator implements StoreValidator {

    @Autowired
    private IStoreService storeService;

    @Autowired
    private ISmDeviceService deviceService;

    /**
     * 逻辑删除前校验
     * @param ids 店铺id列表
     */
    @Override
    public ValidateResult preLogicDel(List<Long> ids) {
        if (CollectionUtils.isEmpty(ids)) {
            return error("id列表不能为空");
        }

        // 判断是否存在设备
        if (this.hasDevice(ids)) {
            return error("当前店铺存在设备，不能删除");
        }

        return success();
    }

    /**
     * 判断店铺是否存在设备
     * @param ids 店铺id列表
     */
    @Override
    public boolean hasDevice(List<Long> ids) {
        if (CollectionUtils.isEmpty(ids)) {
            return false;
        }
        SmDeviceQuery query = new SmDeviceQuery();
        query.setStoreIds(ids);
        return deviceService.selectCount(query) > 0;
    }
}
