package com.ruoyi.web.controller.app;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.UserType;
import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVo;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.web.core.annotation.UserTypePermission;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 设备分组Controller
 * @author 辉
 * 2024/3/5
 */
@Api(tags = "设备分组")
@RestController
@RequestMapping("/app/group")
public class AppDeviceGroupController extends BaseController {

    @Autowired
    private IStoreService smDeviceGroupService;

    /**
     * 查询设备分组列表
     */
    @UserTypePermission({UserType.LANDLORD})
    @ApiOperation("查询设备分组列表")
    @GetMapping("/list")
    public TableDataInfo list(StoreQuery store) {
        startPage();
        store.setUserId(getUserId());
        List<StoreVo> list = smDeviceGroupService.selectSmStore(store);
        return getDataTable(list);
    }

    /**
     * 修改设备分组信息
     * @param store
     * @return
     */
    @DataScope
    @UserTypePermission({UserType.LANDLORD})
    @ApiOperation("修改设备分组信息")
    @PutMapping
    public AjaxResult edit(@RequestBody Store store) {
        store.setCreateTime(null);
        store.setCreateBy(null);
        store.setUserId(null);
        return AjaxResult.success(smDeviceGroupService.updateSmStore(store));
    }

    /**
     * 删除设备分组信息
     * @param groupId
     * @return
     */
    @UserTypePermission({UserType.LANDLORD})
    @ApiOperation("删除设备分组信息")
    @DeleteMapping("/{groupId}")
    public AjaxResult delete(@PathVariable Long groupId) {
        return AjaxResult.success(smDeviceGroupService.deleteSmStoreById(groupId));
    }

    /**
     * 新增设备分组
     * @param store
     * @return
     */
    @UserTypePermission({UserType.LANDLORD})
    @ApiOperation("新增设备分组")
    @PostMapping
    public AjaxResult add(@RequestBody Store store) {
        store.setUserId(getUserId());
        return AjaxResult.success(smDeviceGroupService.insertSmStore(store));
    }

    @UserTypePermission({UserType.LANDLORD})
    @ApiOperation("调整分组位置")
    @PutMapping("/changeSort")
    public AjaxResult changeSort(@RequestBody List<Store> list) {
        return AjaxResult.success(smDeviceGroupService.changeSort(list));
    }

    @ApiOperation("获取当前用户分组列表及其数量")
    @GetMapping("/listCount")
    public AjaxResult listCount(Store store) {
        store.setUserId(getUserId());
        return AjaxResult.success(smDeviceGroupService.listCount(store));
    }
}
