package com.ruoyi.web.controller.ss;

import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.ValidGroup;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.ss.store.domain.StoreQuery;
import com.ruoyi.ss.store.domain.StoreVo;
import com.ruoyi.ss.store.service.StoreValidator;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.store.domain.Store;
import com.ruoyi.ss.store.service.IStoreService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商户Controller
 *
 * @author 邱贞招
 * @date 2024-02-21
 */
@RestController
@RequestMapping("/ss/store")
public class StoreController extends BaseController
{
    @Autowired
    private IStoreService storeService;

    @Autowired
    private StoreValidator storeValidator;

    /**
     * 查询商户列表
     */
    @PreAuthorize("@ss.hasPermi('ss.store:list')")
    @GetMapping("/list")
    public TableDataInfo list(StoreQuery store)
    {
        startPage();
        List<StoreVo> list = storeService.selectSmStore(store);
        return getDataTable(list);
    }

    /**
     * 导出商户列表
     */
    @PreAuthorize("@ss.hasPermi('ss.store:export')")
    @Log(title = "商户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StoreQuery store)
    {
        List<StoreVo> list = storeService.selectSmStore(store);
        ExcelUtil<StoreVo> util = new ExcelUtil<StoreVo>(StoreVo.class);
        util.exportExcel(response, list, "商户数据");
    }

    /**
     * 获取商户详细信息
     */
    @PreAuthorize("@ss.hasPermi('ss.store:query')")
    @GetMapping(value = "/{groupId}")
    public AjaxResult getInfo(@PathVariable("groupId") Long groupId)
    {
        return success(storeService.selectSmStoreById(groupId));
    }

    /**
     * 新增商户
     */
    @PreAuthorize("@ss.hasPermi('ss.store:add')")
    @Log(title = "商户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Store store)
    {
        return toAjax(storeService.insertSmStore(store));
    }

    /**
     * 修改商户
     */
    @PreAuthorize("@ss.hasPermi('ss.store:edit')")
    @Log(title = "商户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Store store)
    {
        return toAjax(storeService.updateSmStore(store));
    }

    /**
     * 删除商户
     */
    @PreAuthorize("@ss.hasPermi('ss.store:remove')")
    @Log(title = "商户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{storeIds}")
    public AjaxResult remove(@PathVariable Long[] storeIds)
    {
        List<Long> ids = Arrays.asList(storeIds);
        ServiceUtil.assertion(storeValidator.preLogicDel(ids));
        return toAjax(storeService.logicDel(ids));
    }
}
